using Autofac;
using FitConnect.Encryption;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using Microsoft.IdentityModel.Tokens;
using MockContainer;
using NUnit.Framework;

namespace IntegrationTests;

[TestFixture]
public class CertificateValidation {
    private MockSettings _settings = null!;
    private ILogger _logger = null!;
    private CertificateHelper _certificateHelper = null!;

    [SetUp]
    public void Setup() {
        var container = Container.Create();
        _settings = container.Resolve<MockSettings>();

        _logger = LoggerFactory.Create(
            builder => {
                builder.AddConsole();
                builder.SetMinimumLevel(LogLevel.Debug);
            }).CreateLogger("E2E Test");

        _certificateHelper = new CertificateHelper(_logger);
    }

    [Test]
    public void CheckPublicKeyEncryption() {
        _certificateHelper.ValidateCertificate(new JsonWebKey(_settings.PublicKeyEncryption))
            .Should().BeTrue();
    }

    [Test]
    public void CheckPrivateKeyDecryption() {
        _certificateHelper.ValidateCertificate(new JsonWebKey(_settings.PrivateKeyDecryption))
            .Should().BeTrue();
    }
}
